@@ -9,11 +9,12 @@
 
 #include "kaccounts_export.h"
 
-#include <KJob>
 #include <Accounts/Account>
+#include <KJob>
 
-namespace Accounts {
-    class Manager;
+namespace Accounts
+{
+class Manager;
 }
 
 /**
@@ -46,7 +47,7 @@ public:
      */
     GetCredentialsJob(Accounts::AccountId id, const QString &authMethod = QString(), const QString &authMechanism = QString(), QObject *parent = nullptr);
 
-    ~GetCredentialsJob();
+    ~GetCredentialsJob() override;
     /**
      * Starts the credentials job
      */
@@ -75,8 +76,8 @@ public:
 
 private:
     class Private;
-    Private * const d;
+    Private *const d;
     Q_PRIVATE_SLOT(d, void getCredentials())
 };
 
-#endif //GET_CREDENTIALS_JOB_H
+#endif // GET_CREDENTIALS_JOB_H
